# Changes

## 1.0.4 2020-06-20
* enable truncate spaces in StringEdit.generate_text()

## 1.0.3 2018-06-07
* fix bug that ambiguous character width was counted as 2

## 1.0.2 2018-06-06
* fix bug that package doesn't contain README.md

## 1.0.1, 2018-06-06
* update README.md and README.rst

## 1.0.0, 2018-06-03
* First Release
